=======================================
Reporting bugs, requesting new features
=======================================

If you find a bug, unclear documentation, or would like to add a new feature to Neo,
please go to https://github.com/NeuralEnsemble/python-neo/issues/.


Searching the issue tracker
===========================

Before creating a new issue, please read through the existing list of issues
to check whether someone else has already created a similar one.
You can also use Github's search capabilities for this.

If you do find an existing issue, then please add a comment to say that you
have also encountered this bug, or would like this feature to be added.

If your issue is similar, but not identical, to one or more existing issues,
then create a new issue making reference to the existing one,
and explaining how your issue differs.


Creating a new issue
====================

To create a new issue, click on "New issue", then click "Get started" next to the appropriate template:

- "Bug report"
- "Confusing documentation"
- "Feature request"

Please fill in all the information requested in the template.
If you'd like to open an issue that isn't covered by these three options, click "Open a blank issue".
